Crate bears

Crate bears 

Structs

Cli
ValueSets

Enums

Action
Variants of the Action enum encapsulate the different actions a user can select, exposing the different capabilities of the library.
ValueSet