DepNode

Struct DepNode 

pub struct DepNode<'a> {
    pub task: &'a Task,
    pub children: Vec<DepNode<'a>>,
    pub cycle: bool,
    pub seen: bool,
}

Fields

task: &'a Taskchildren: Vec<DepNode<'a>>cycle: bool

True when this node was already seen on the current path (cycle).

seen: bool

True when this node was already fully expanded on an earlier path (DAG diamond deduplication). Distinct from cycle.